==> sagua_0.2.0-1.tar.gz: sagua-0.2.0/src/dirbrowsedlg.cc <==
// Sagua is music player. 
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file dirbrowsedlg.cc
/// @brief Class for directory selection dialog source file.

#include "../include/dirbrowsedlg.h"

DirBrowseDlg::DirBrowseDlg()
{
    set_resizable(true);
    set_size_request(250, 400);
    
    Gtk::VBox* mainBox_ = get_vbox();

    mainBox_->pack_start(dirBrowseWnd_);

    dirBrowseWnd_.signalSelected().connect(
	sigc::mem_fun(*this, &DirBrowseDlg::OnSelected) );

    Gtk::Button* cancelBtn = add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
    cancelBtn->signal_clicked().connect(
	sigc::mem_fun(*this, &DirBrowseDlg::OnBtnCancel) );

    Gtk::Button* okBtn = add_button(Gtk::Stock::OK, Gtk::RESPONSE_OK);
    okBtn->signal_clicked().connect(
	sigc::mem_fun(*this, &DirBrowseDlg::OnBtnOk) ); 

    show_all_children();
}

DirBrowseDlg::~DirBrowseDlg()
{}

/// @brief Callback function when select(double click or else...) directory column.
///
/// Store selected directory path and close dialog with RESPONSE_OK.
void DirBrowseDlg::OnSelected()
{
    selectedDirectory_ = dirBrowseWnd_.SelectedDirectory();
    
    hide();
    response(Gtk::RESPONSE_OK);
}

/// @brief Callback function when cancel button is pressed.
void DirBrowseDlg::OnBtnCancel()
{
    hide();
}

/// @brief Callback function when ok button is pressed.
void DirBrowseDlg::OnBtnOk()
{
    selectedDirectory_ = dirBrowseWnd_.SelectedDirectoryFromIter();

    hide();
}

==> sagua_0.2.1-1.tar.gz: sagua-0.2.1/src/dirbrowsedlg.cc <==
// Sagua is music player. 
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file dirbrowsedlg.cc
/// @brief Class for directory selection dialog source file.

#include "../include/dirbrowsedlg.h"

DirBrowseDlg::DirBrowseDlg()
{
    set_resizable(true);
    set_size_request(250, 400);
    
    Gtk::VBox* const mainBox_ = get_vbox();

    mainBox_->pack_start(dirBrowseWnd_);

    dirBrowseWnd_.signalSelected().connect(
	sigc::mem_fun(*this, &DirBrowseDlg::OnSelected) );

    Gtk::Button* const cancelBtn = add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
    cancelBtn->signal_clicked().connect(
	sigc::mem_fun(*this, &DirBrowseDlg::OnBtnCancel) );

    Gtk::Button* const okBtn = add_button(Gtk::Stock::OK, Gtk::RESPONSE_OK);
    okBtn->signal_clicked().connect(
	sigc::mem_fun(*this, &DirBrowseDlg::OnBtnOk) ); 

    show_all_children();
}

DirBrowseDlg::~DirBrowseDlg()
{}

/// @brief Callback function when select(double click or else...) directory column.
///
/// Store selected directory path and close dialog with RESPONSE_OK.
void DirBrowseDlg::OnSelected()
{
    selectedDirectory_ = dirBrowseWnd_.SelectedDirectory();
    
    hide();
    response(Gtk::RESPONSE_OK);
}

/// @brief Callback function when cancel button is pressed.
void DirBrowseDlg::OnBtnCancel()
{
    hide();
}

/// @brief Callback function when ok button is pressed.
void DirBrowseDlg::OnBtnOk()
{
    selectedDirectory_ = dirBrowseWnd_.SelectedDirectoryFromIter();

    hide();
}
